# MBASIC Games Library

Classic BASIC games from the CP/M era

## Available Games

### 23Matches



**Year:** 1980s
**Tags:** 

**[Download 23matches.bas](23matches.bas)**

---

### 3Dplot



**Year:** 1980s
**Tags:** 

**[Download 3dplot.bas](3dplot.bas)**

---

### Aceyducey



**Year:** 1980s
**Tags:** 

**[Download aceyducey.bas](aceyducey.bas)**

---

### Amazing



**Year:** 1980s
**Tags:** 

**[Download amazing.bas](amazing.bas)**

---

### Animal



**Year:** 1980s
**Tags:** 

**[Download animal.bas](animal.bas)**

---

### Awari



**Year:** 1980s
**Tags:** 

**[Download awari.bas](awari.bas)**

---

### Bacarrat



**Year:** 1980s
**Tags:** 

**[Download bacarrat.bas](bacarrat.bas)**

---

### Bagels



**Year:** 1980s
**Tags:** 

**[Download bagels.bas](bagels.bas)**

---

### Banner



**Year:** 1980s
**Tags:** 

**[Download banner.bas](banner.bas)**

---

### Basketball



**Year:** 1980s
**Tags:** 

**[Download basketball.bas](basketball.bas)**

---

### Batnum



**Year:** 1980s
**Tags:** 

**[Download batnum.bas](batnum.bas)**

---

### Battle



**Year:** 1980s
**Tags:** 

**[Download battle.bas](battle.bas)**

---

### Blackjack



**Year:** 1980s
**Tags:** 

**[Download blackjack.bas](blackjack.bas)**

---

### Blkjk



**Year:** 1980s
**Tags:** 

**[Download blkjk.bas](blkjk.bas)**

---

### Bombardment



**Year:** 1980s
**Tags:** 

**[Download bombardment.bas](bombardment.bas)**

---

### Bombsaway



**Year:** 1980s
**Tags:** 

**[Download bombsaway.bas](bombsaway.bas)**

---

### Bounce



**Year:** 1980s
**Tags:** 

**[Download bounce.bas](bounce.bas)**

---

### Bowling



**Year:** 1980s
**Tags:** 

**[Download bowling.bas](bowling.bas)**

---

### Boxing



**Year:** 1980s
**Tags:** 

**[Download boxing.bas](boxing.bas)**

---

### Bug



**Year:** 1980s
**Tags:** 

**[Download bug.bas](bug.bas)**

---

### Bullfight



**Year:** 1980s
**Tags:** 

**[Download bullfight.bas](bullfight.bas)**

---

### Bullseye



**Year:** 1980s
**Tags:** 

**[Download bullseye.bas](bullseye.bas)**

---

### Bunny



**Year:** 1980s
**Tags:** 

**[Download bunny.bas](bunny.bas)**

---

### Buzzword



**Year:** 1980s
**Tags:** 

**[Download buzzword.bas](buzzword.bas)**

---

### Calendar

Full-year calendar display program - shows entire year's calendar at once (Creative Computing, 1979)

**Source:** Creative Computing, Morristown, NJ
**Year:** 1979
**Tags:** calendar, display, year-view

**[Download calendar.bas](calendar.bas)**

**Note:** A different calendar program (month/year selector, 1900-2099) is available in the [Utilities Library](../utilities/index.md#calendar)

---

### Change



**Year:** 1980s
**Tags:** 

**[Download change.bas](change.bas)**

---

### Checkers



**Year:** 1980s
**Tags:** 

**[Download checkers.bas](checkers.bas)**

---

### Chemist



**Year:** 1980s
**Tags:** 

**[Download chemist.bas](chemist.bas)**

---

### Chief



**Year:** 1980s
**Tags:** 

**[Download chief.bas](chief.bas)**

---

### Chomp



**Year:** 1980s
**Tags:** 

**[Download chomp.bas](chomp.bas)**

---

### Civilwar



**Year:** 1980s
**Tags:** 

**[Download civilwar.bas](civilwar.bas)**

---

### Combat



**Year:** 1980s
**Tags:** 

**[Download combat.bas](combat.bas)**

---

### Craps



**Year:** 1980s
**Tags:** 

**[Download craps.bas](craps.bas)**

---

### Cube



**Year:** 1980s
**Tags:** 

**[Download cube.bas](cube.bas)**

---

### Depthcharge



**Year:** 1980s
**Tags:** 

**[Download depthcharge.bas](depthcharge.bas)**

---

### Diamond



**Year:** 1980s
**Tags:** 

**[Download diamond.bas](diamond.bas)**

---

### Dice



**Year:** 1980s
**Tags:** 

**[Download dice.bas](dice.bas)**

---

### Digits



**Year:** 1980s
**Tags:** 

**[Download digits.bas](digits.bas)**

---

### Evenwins



**Year:** 1980s
**Tags:** 

**[Download evenwins.bas](evenwins.bas)**

---

### Feesten



**Year:** 1980s
**Tags:** 

**[Download feesten.bas](feesten.bas)**

---

### Flipflop



**Year:** 1980s
**Tags:** 

**[Download flipflop.bas](flipflop.bas)**

---

### Football



**Year:** 1980s
**Tags:** 

**[Download football.bas](football.bas)**

---

### Ftball



**Year:** 1980s
**Tags:** 

**[Download ftball.bas](ftball.bas)**

---

### Furtrader



**Year:** 1980s
**Tags:** 

**[Download furtrader.bas](furtrader.bas)**

---

### Gameofevenwins



**Year:** 1980s
**Tags:** 

**[Download gameofevenwins.bas](gameofevenwins.bas)**

---

### Golf



**Year:** 1980s
**Tags:** 

**[Download golf.bas](golf.bas)**

---

### Gomoko



**Year:** 1980s
**Tags:** 

**[Download gomoko.bas](gomoko.bas)**

---

### Guess



**Year:** 1980s
**Tags:** 

**[Download guess.bas](guess.bas)**

---

### Gunner



**Year:** 1980s
**Tags:** 

**[Download gunner.bas](gunner.bas)**

---

### Hammurabi



**Year:** 1980s
**Tags:** 

**[Download hammurabi.bas](hammurabi.bas)**

---

### Hangman



**Year:** 1980s
**Tags:** 

**[Download hangman.bas](hangman.bas)**

---

### Hangman1



**Year:** 1980s
**Tags:** 

**[Download hangman1.bas](hangman1.bas)**

---

### Hello



**Year:** 1980s
**Tags:** 

**[Download hello.bas](hello.bas)**

---

### Hi-Lo



**Year:** 1980s
**Tags:** 

**[Download hi-lo.bas](hi-lo.bas)**

---

### Highiq



**Year:** 1980s
**Tags:** 

**[Download highiq.bas](highiq.bas)**

---

### Hockey



**Year:** 1980s
**Tags:** 

**[Download hockey.bas](hockey.bas)**

---

### Horserace



**Year:** 1980s
**Tags:** 

**[Download horserace.bas](horserace.bas)**

---

### Hurkle



**Year:** 1980s
**Tags:** 

**[Download hurkle.bas](hurkle.bas)**

---

### Kalfeest



**Year:** 1980s
**Tags:** 

**[Download kalfeest.bas](kalfeest.bas)**

---

### Kinema



**Year:** 1980s
**Tags:** 

**[Download kinema.bas](kinema.bas)**

---

### King



**Year:** 1980s
**Tags:** 

**[Download king.bas](king.bas)**

---

### Lem



**Year:** 1980s
**Tags:** 

**[Download lem.bas](lem.bas)**

---

### Letter



**Year:** 1980s
**Tags:** 

**[Download letter.bas](letter.bas)**

---

### Life



**Year:** 1980s
**Tags:** 

**[Download life.bas](life.bas)**

---

### Lifefortwo



**Year:** 1980s
**Tags:** 

**[Download lifefortwo.bas](lifefortwo.bas)**

---

### Lifscore



**Year:** 1980s
**Tags:** 

**[Download lifscore.bas](lifscore.bas)**

---

### Litquiz



**Year:** 1980s
**Tags:** 

**[Download litquiz.bas](litquiz.bas)**

---

### Love



**Year:** 1980s
**Tags:** 

**[Download love.bas](love.bas)**

---

### Lunar



**Year:** 1980s
**Tags:** 

**[Download lunar.bas](lunar.bas)**

---

### Massa



**Year:** 1980s
**Tags:** 

**[Download massa.bas](massa.bas)**

---

### Mastermind



**Year:** 1980s
**Tags:** 

**[Download mastermind.bas](mastermind.bas)**

---

### Mathdice



**Year:** 1980s
**Tags:** 

**[Download mathdice.bas](mathdice.bas)**

---

### Mugwump



**Year:** 1980s
**Tags:** 

**[Download mugwump.bas](mugwump.bas)**

---

### Name



**Year:** 1980s
**Tags:** 

**[Download name.bas](name.bas)**

---

### Nicomachus



**Year:** 1980s
**Tags:** 

**[Download nicomachus.bas](nicomachus.bas)**

---

### Nim



**Year:** 1980s
**Tags:** 

**[Download nim.bas](nim.bas)**

---

### Number



**Year:** 1980s
**Tags:** 

**[Download number.bas](number.bas)**

---

### Onecheck



**Year:** 1980s
**Tags:** 

**[Download onecheck.bas](onecheck.bas)**

---

### Orbit



**Year:** 1980s
**Tags:** 

**[Download orbit.bas](orbit.bas)**

---

### Ozdot



**Year:** 1980s
**Tags:** 

**[Download ozdot.bas](ozdot.bas)**

---

### Pizza



**Year:** 1980s
**Tags:** 

**[Download pizza.bas](pizza.bas)**

---

### Poetry



**Year:** 1980s
**Tags:** 

**[Download poetry.bas](poetry.bas)**

---

### Poker



**Year:** 1980s
**Tags:** 

**[Download poker.bas](poker.bas)**

---

### Qubit



**Year:** 1980s
**Tags:** 

**[Download qubit.bas](qubit.bas)**

---

### Queen



**Year:** 1980s
**Tags:** 

**[Download queen.bas](queen.bas)**

---

### Reverse



**Year:** 1980s
**Tags:** 

**[Download reverse.bas](reverse.bas)**

---

### Rocket



**Year:** 1980s
**Tags:** 

**[Download rocket.bas](rocket.bas)**

---

### Rockscissors



**Year:** 1980s
**Tags:** 

**[Download rockscissors.bas](rockscissors.bas)**

---

### Roulette



**Year:** 1980s
**Tags:** 

**[Download roulette.bas](roulette.bas)**

---

### Russianroulette



**Year:** 1980s
**Tags:** 

**[Download russianroulette.bas](russianroulette.bas)**

---

### Salvo



**Year:** 1980s
**Tags:** 

**[Download salvo.bas](salvo.bas)**

---

### Slalom



**Year:** 1980s
**Tags:** 

**[Download slalom.bas](slalom.bas)**

---

### Slots



**Year:** 1980s
**Tags:** 

**[Download slots.bas](slots.bas)**

---

### Spacewar



**Year:** 1980s
**Tags:** 

**[Download spacewar.bas](spacewar.bas)**

---

### Splat



**Year:** 1980s
**Tags:** 

**[Download splat.bas](splat.bas)**

---

### Star



**Year:** 1980s
**Tags:** 

**[Download star.bas](star.bas)**

---

### Stars



**Year:** 1980s
**Tags:** 

**[Download stars.bas](stars.bas)**

---

### Startrek



**Year:** 1980s
**Tags:** 

**[Download startrek.bas](startrek.bas)**

---

### Stockmarket



**Year:** 1980s
**Tags:** 

**[Download stockmarket.bas](stockmarket.bas)**

---

### Suite



**Year:** 1980s
**Tags:** 

**[Download suite.bas](suite.bas)**

---

### Superstartrek



**Year:** 1980s
**Tags:** 

**[Download superstartrek.bas](superstartrek.bas)**

---

### Superstartrekins



**Year:** 1980s
**Tags:** 

**[Download superstartrekins.bas](superstartrekins.bas)**

---

### Survival



**Author:** R Logan & Ian Lycholm CBASIC 2 VER
**Year:** 1982
**Tags:** 

**[Download survival.bas](survival.bas)**

---

### Synonym



**Year:** 1980s
**Tags:** 

**[Download synonym.bas](synonym.bas)**

---

### Target



**Year:** 1980s
**Tags:** 

**[Download target.bas](target.bas)**

---

### Tictactoe1



**Year:** 1980s
**Tags:** 

**[Download tictactoe1.bas](tictactoe1.bas)**

---

### Tictactoe2



**Year:** 1980s
**Tags:** 

**[Download tictactoe2.bas](tictactoe2.bas)**

---

### Tower



**Year:** 1980s
**Tags:** 

**[Download tower.bas](tower.bas)**

---

### Train



**Year:** 1980s
**Tags:** 

**[Download train.bas](train.bas)**

---

### Trap



**Year:** 1980s
**Tags:** 

**[Download trap.bas](trap.bas)**

---

### War



**Year:** 1980s
**Tags:** 

**[Download war.bas](war.bas)**

---

### Weekday



**Year:** 1980s
**Tags:** 

**[Download weekday.bas](weekday.bas)**

---

### Word



**Year:** 1980s
**Tags:** 

**[Download word.bas](word.bas)**

---

## How to Use

1. **Download** the .bas file you want to use
2. **Open MBASIC** in your preferred UI (Web, Tkinter, Curses, or CLI)
3. **Open the file:**
   - **Web/Tkinter UI:** Click File → Open, select the downloaded file
   - **CLI:** Type `LOAD "filename.bas"`
4. **Run:** Type `RUN` or press the Run button

## About These Games

These programs are from the CP/M and early PC era (1970s-1980s), 
preserved from historical archives including OAK, Simtel, and CP/M CD-ROMs.
